/* 

  TIM.2- Things In Motion, version 2

  TIM (Things In Motion) is a set of related programs whose goal is to
  facilitate the visualization of time-series positional data.

  The data to be displayed can be either read from an existing file, or they
  can be generated by a simulation process and asynchronously displayed by a
  visualization process as the data are being generated. The visualization
  and simulation processes do not need to run on the same system; this
  allows the simulation process to be run on a large remote
  "number-cruncher", while the visualization can be done on a local system.

  TIM uses DIVERSE's dpf and dtk modules to allow the data to be viewed on
  systems ranging from a laptop to a multi-screen immersive display such as
  a CAVE(tm).

  Authors:
      John Kelso, Steve Satterfield
      Scientific Applications & Visualization Group
           SAVG web page: http://math.nist.gov/mcsd/savg/
      Mathematical & Computational Science Division
           MCSD web page: http://math.nist.gov/mcsd/
      National Institute of Standards and Technology
           NIST web page: http://www.nist.gov/


  For information about this software contact John Kelso, kelso@nist.gov

  "This software was developed at the National Institute of Standards and
  Technology by employees of the Federal Government in the course of their
  official duties. Pursuant to title 17 Section 105 of the United States
  Code this software is not subject to copyright protection and is in the
  public domain. This is an experimental system.  NIST assumes no
  responsibility whatsoever for its use by other parties, and makes no
  guarantees, expressed or implied, about its quality, reliability, or any
  other characteristic.

 We would appreciate acknowledgement if the software is used."

*/

/*    reads a tim frames file via stdin and writes the frames data to stdout
      
      checks for syntax and normalizes the data

      blank lines, and anything after and including a # will be ignored
      
      the format for the frames file is a series of positions, each specified
      by an XYZ translation (3 floats) and xyzw quaternion (4 floats)
      
      No DIVERSE or Performer code required
*/

#include <stdio.h>
#include "normalize.C"
#include "getString.C"


int main (int argc, char **argv) {
  // crank through the data, checking for errors and tossing comments
  char *input = NULL ;
  int n = 0 ;
  while((getString(&input))!=EOF) {
    n++ ;
    if (normalize(input)) {
      // is the line of the correct format?
      float tx,ty,tz,qx,qy,qz,qw ;
      if ((sscanf(input, "%f %f %f %f %f %f %f", 
		  &tx, &ty, &tz, &qx, &qy, &qz, &qw)) != 7) {
	fprintf(stderr,
		"Error: normalize: line %d non-conformant: \"%s\"\n", n, input) ;
	return 1 ;
      } else {
	printf("%s\n",input) ;
      }
    }
  }
}
  
