/* 

  TIM.2- Things In Motion, version 2

  TIM (Things In Motion) is a set of related programs whose goal is to
  facilitate the visualization of time-series positional data.

  The data to be displayed can be either read from an existing file, or they
  can be generated by a simulation process and asynchronously displayed by a
  visualization process as the data are being generated. The visualization
  and simulation processes do not need to run on the same system; this
  allows the simulation process to be run on a large remote
  "number-cruncher", while the visualization can be done on a local system.

  TIM uses DIVERSE's dpf and dtk modules to allow the data to be viewed on
  systems ranging from a laptop to a multi-screen immersive display such as
  a CAVE(tm).

  Authors:
      John Kelso, Steve Satterfield
      Scientific Applications & Visualization Group
           SAVG web page: http://math.nist.gov/mcsd/savg/
      Mathematical & Computational Science Division
           MCSD web page: http://math.nist.gov/mcsd/
      National Institute of Standards and Technology
           NIST web page: http://www.nist.gov/


  For information about this software contact John Kelso, kelso@nist.gov

  "This software was developed at the National Institute of Standards and
  Technology by employees of the Federal Government in the course of their
  official duties. Pursuant to title 17 Section 105 of the United States
  Code this software is not subject to copyright protection and is in the
  public domain. This is an experimental system.  NIST assumes no
  responsibility whatsoever for its use by other parties, and makes no
  guarantees, expressed or implied, about its quality, reliability, or any
  other characteristic.

 We would appreciate acknowledgement if the software is used."

*/

// sends every Nth line of stdin to stdout, where the first line is number
// 0, so always sends the first line

// --group g means to treat every "g" lines as a single line for counting
// --purposes.  If not given defaults to 1

// usage: every [--verbose] [--group g] N 

#include <stdio.h>
#include "getString.C"

void usage(char *name) {
  fprintf(stderr,
	  "Usage: %s [--verbose] [--group g] n\n"
	  "where n is the number of lines to skip in a loop\n"
	  "      g is the number of lines to group together to count\n"
	  "        as one line- default is 1\n"
	  , name) ;
}

int main (int argc, char **argv) {
  int every ;
  int group = 1 ;
  int verbose = 0 ;

  char *name = argv[0] ;

  int i = 1 ;
  
  while (i<argc) {
    if ((strstr("--verbose",argv[i]))!=NULL) {
      verbose = 1 ;
      i++ ;

    } else if ((strstr("--group",argv[i]))!=NULL) {
      i++ ;
      if (i<argc) {
	if (1 != sscanf(argv[i],"%d",&group)) {
	  fprintf(stderr, 
		  "Error: %s:invalid group = %s\n",name, argv[i]) ;
	  usage(name) ;
	  return 1 ;
	} else if (group <= 0) {
	  fprintf(stderr, 
		  "Error: %s: invalid group = %s\n",name, argv[i]) ;
	  usage(name) ;
	  return 1 ;
	} else {
	  i++ ;
	}
      } else {
	fprintf(stderr, 
		   "Error: %s: No --group parameter\n", name) ;
	usage(name) ;
	return 1 ;
      }
      
    } else { //N
      if((sscanf(argv[i],"%d",&every))==1) {
	if(every<=0) {
	  usage(name) ; 
	  return 1 ;
	}
      } else {
	usage(name) ; 
	return 1 ;
      }
      i++ ;
    }
  }
  
  if (verbose) 
    fprintf(stderr, "%s: N=%d, g=%d, writing every %d groups of %d lines\n",
	    name, every, group, every, group) ;

  // crank through the data, tossing the every N*g lines
  int n = 0 ;
  char *input = NULL ;
  while((getString(&input))!=EOF) {
    if((n/group)%every==0) {
      printf("%s\n",input) ;
    }
    n++ ;
  }
}

