/* 

  TIM.2- Things In Motion, version 2

  TIM (Things In Motion) is a set of related programs whose goal is to
  facilitate the visualization of time-series positional data.

  The data to be displayed can be either read from an existing file, or they
  can be generated by a simulation process and asynchronously displayed by a
  visualization process as the data are being generated. The visualization
  and simulation processes do not need to run on the same system; this
  allows the simulation process to be run on a large remote
  "number-cruncher", while the visualization can be done on a local system.

  TIM uses DIVERSE's dpf and dtk modules to allow the data to be viewed on
  systems ranging from a laptop to a multi-screen immersive display such as
  a CAVE(tm).

  Authors:
      John Kelso, Steve Satterfield
      Scientific Applications & Visualization Group
           SAVG web page: http://math.nist.gov/mcsd/savg/
      Mathematical & Computational Science Division
           MCSD web page: http://math.nist.gov/mcsd/
      National Institute of Standards and Technology
           NIST web page: http://www.nist.gov/


  For information about this software contact John Kelso, kelso@nist.gov

  "This software was developed at the National Institute of Standards and
  Technology by employees of the Federal Government in the course of their
  official duties. Pursuant to title 17 Section 105 of the United States
  Code this software is not subject to copyright protection and is in the
  public domain. This is an experimental system.  NIST assumes no
  responsibility whatsoever for its use by other parties, and makes no
  guarantees, expressed or implied, about its quality, reliability, or any
  other characteristic.

 We would appreciate acknowledgement if the software is used."

*/

// generates exampleData.frames and exampleData.hpr

// assumes four objects are in exampleData.objects

#include <math.h>
#include <dtk.h>

#define INC (1.f)

int main () {

  dtkMatrix m ;
  float xt, yt, zt ;
  float xq, yq, zq, wq ;
  float h, p, r ;

  
  FILE *hpr ;
  hpr = fopen("exampleData.hpr", "w") ;
  if (hpr) {
    for (h=0; h<360; h+=10.f) {
      for (p=0; p<360; p+=10.f) {
	for (r=0; r<360; r+=10.f) {
	  fprintf(hpr, "0 0 0 %3.3f %3.3f %3.3f\n", h, p, r) ;
	}
      }
    }
    fclose(hpr) ;
  } else {
    fprintf(stderr, "Can't open exampleData.hpr for writing\n") ;
  }
  
    
  FILE *frame ;
  frame = fopen("exampleData.frames", "w") ;
  if (frame) {
    for (float d=0.f; d<360.f; d+=INC) {
      float rad = d*M_PI/180.f ;
      
      // object 1 spins around the Y axis one unit out
      m.rotateHPR(0.f, 0.f, d) ;
      m.translate(cos(-rad), 0.f, sin(-rad)) ;
      m.quat(&xq, &yq, &zq, &wq) ;
      m.translate(&xt, &yt, &zt) ;
      m.rotateHPR(&h, &p, &r) ;
      fprintf(frame,"%f %f %f %f %f %f %f\n",
	     xt, yt, zt, xq, yq, zq, wq) ;
      m.identity() ;
      
      // object 2 spins around the Y axis in place
      m.rotateHPR(0.f, 0.f, d) ;
      m.quat(&xq, &yq, &zq, &wq) ;
      m.rotateHPR(&h, &p, &r) ;
      fprintf(frame,"%f %f %f %f %f %f %f\n",
	     0.f, 0.f, 0.f, xq, yq, zq, wq) ;
      m.identity() ;
      
      // object 3 goes back and forth on the X axis, in line with object 1
      fprintf(frame,"%f %f %f %f %f %f %f\n",
	     cos(rad), 0.f, 0.f, 0.f, 0.f, 0.f, 1.f) ;
      
      
      // object 4 translates all 3 dimensions in line with object 1
      m.rotateHPR(180, 0.f, 0.f) ;
      m.translate(cos(-rad), cos(rad), sin(-rad)) ;
      
      m.quat(&xq, &yq, &zq, &wq) ;
      m.translate(&xt, &yt, &zt) ;
      m.rotateHPR(&h, &p, &r) ;
      fprintf(frame,"%f %f %f %f %f %f %f\n",
	     xt, yt, zt, xq, yq, zq, wq) ;
      m.identity() ;
    }
    fclose(frame) ;
  } else {
    fprintf(stderr, "Can't open exampleData.frames for writing\n") ;
  }
  return 0 ;
}
