#!/bin/sh 

#  TIM.2- Things In Motion, version 2
#
#  TIM (Things In Motion) is a set of related programs whose goal is to
#  facilitate the visualization of time-series positional data.
#
#  The data to be displayed can be either read from an existing file, or they
#  can be generated by a simulation process and asynchronously displayed by a
#  visualization process as the data are being generated. The visualization
#  and simulation processes do not need to run on the same system; this
#  allows the simulation process to be run on a large remote
#  "number-cruncher", while the visualization can be done on a local system.
#
#  TIM uses DIVERSE's dpf and dtk modules to allow the data to be viewed on
#  systems ranging from a laptop to a multi-screen immersive display such as
#  a CAVE(tm).
#
#  Authors:
#      John Kelso, Steve Satterfield
#      Scientific Applications & Visualization Group
#           SAVG web page: http://math.nist.gov/mcsd/savg/
#      Mathematical & Computational Science Division
#           MCSD web page: http://math.nist.gov/mcsd/
#      National Institute of Standards and Technology
#           NIST web page: http://www.nist.gov/
#
#
#  For information about this software contact John Kelso, kelso@nist.gov
#
#  "This software was developed at the National Institute of Standards and
#  Technology by employees of the Federal Government in the course of their
#  official duties. Pursuant to title 17 Section 105 of the United States
#  Code this software is not subject to copyright protection and is in the
#  public domain. This is an experimental system.  NIST assumes no
#  responsibility whatsoever for its use by other parties, and makes no
#  guarantees, expressed or implied, about its quality, reliability, or any
#  other characteristic.
#
# We would appreciate acknowledgement if the software is used."

# frame time
time=".03"

# comment this out to derease spewage
#spew="--verbose"

dtk-destroySharedMem exampleData >/dev/null 2>&1

if [ -e exampleData.seq ] ; then
    \rm -f exampleData.seq
fi

if [ -e exampleData.hpr ] ; then
    \rm -f exampleData.hpr
fi

if [ -e exampleData.frames ] ; then
    \rm -f exampleData.frames
fi

if [ -e exampleData.seq ] ; then
    echo sequence file not deleted
fi

# creates exampleData.hpr and exampleData.frames
./exampleData 

# uncomment to remove Performer spewage
export PFNFYLEVEL=0

# uncomment DIVERSE spewage
#export DTK_SPEW=warning

echo; echo; echo ; echo "First as a sequence file..." ; echo

tim.2 --time $time \
    --frames exampleData.frames \
    --objects ../data/exampleData.objects \
    --sequence exampleData.seq $spew

diversifly --examine exampleData.seq

echo; echo; echo ; echo "Now using shared memory and diversifly...." ; echo
tim.2 --time $time --segment exampleData \
    --frames exampleData.frames \
    --objects ../data/exampleData.objects \
    $spew

echo; echo; echo ; echo "Same thing, but --first 135 --last 135 --every 2 ...." ; echo
tim.2 --first 135 --last 135 --every 2 \
    --frames exampleData.frames \
    --time $time --segment exampleData \
    --objects ../data/exampleData.objects \
    $spew

echo; echo; echo ; echo "Same thing, but using stdin- not in a loop...." ; echo
cat exampleData.frames | tim.2 --time $time \
    --objects ../data/exampleData.objects \
    $spew --segment exampleData 


echo; echo; echo ; echo "Same thing, but skipping first 180 frames...." ; echo
cat exampleData.frames | tim.2 --first 180 --time $time \
    --objects ../data/exampleData.objects \
    $spew

echo; echo; echo ; echo "Same thing, but using infinite stdin- in a loop...." ; echo
cat exampleData.frames | ./loop | tim.2 --time $time \
    --objects ../data/exampleData.objects \
    $spew --segment exampleData 

echo; echo; echo ; echo "Same thing, but every 5th frame...." ; echo
cat exampleData.frames | ./loop | tim.2 --every 5 --time $time \
    --objects ../data/exampleData.objects \
    $spew --segment exampleData 

echo; echo; echo ; echo "Now using shared memory and savgfly...." ; echo
tim.2  --savgfly trackball --time $time \
    --frames exampleData.frames \
    --objects ../data/exampleData.objects \
    $spew --segment exampleData 
