/* 

  TIM.2- Things In Motion, version 2

  TIM (Things In Motion) is a set of related programs whose goal is to
  facilitate the visualization of time-series positional data.

  The data to be displayed can be either read from an existing file, or they
  can be generated by a simulation process and asynchronously displayed by a
  visualization process as the data are being generated. The visualization
  and simulation processes do not need to run on the same system; this
  allows the simulation process to be run on a large remote
  "number-cruncher", while the visualization can be done on a local system.

  TIM uses DIVERSE's dpf and dtk modules to allow the data to be viewed on
  systems ranging from a laptop to a multi-screen immersive display such as
  a CAVE(tm).

  Authors:
      John Kelso, Steve Satterfield
      Scientific Applications & Visualization Group
           SAVG web page: http://math.nist.gov/mcsd/savg/
      Mathematical & Computational Science Division
           MCSD web page: http://math.nist.gov/mcsd/
      National Institute of Standards and Technology
           NIST web page: http://www.nist.gov/


  For information about this software contact John Kelso, kelso@nist.gov

  "This software was developed at the National Institute of Standards and
  Technology by employees of the Federal Government in the course of their
  official duties. Pursuant to title 17 Section 105 of the United States
  Code this software is not subject to copyright protection and is in the
  public domain. This is an experimental system.  NIST assumes no
  responsibility whatsoever for its use by other parties, and makes no
  guarantees, expressed or implied, about its quality, reliability, or any
  other characteristic.

 We would appreciate acknowledgement if the software is used."

*/

/* 
   reads stdin and writes it to stdout in a loop
   
   No DIVERSE or Performer code required
*/

#include <signal.h>
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <math.h>
#include <unistd.h>

#include "getString.C"

// how many lines to allocate at a time
#define LINES (5)

int running = 1;

void signal_catcher(int sig)
{
  running = 0;
}

void usage(char *name) {
  fprintf(stderr, 
	  "Usage: %s  [--sleep z]\n"
	  "where z is the number of seconds (float) to wait before\n "
	  "starting to write data- default is to not sleep\n"
	  , name) ;
}

int main(int argc, char **argv) {
  
  float ztime = 0.f ;
  int setSleep = 0 ;
  
  char *name = strdup(argv[0]) ;

  signal(SIGTERM, signal_catcher);
  signal(SIGINT, signal_catcher);
  
  // process optional argument
  if (argc>=2) {
    if ((strstr("--sleep",argv[1]))!=NULL) {
      if(argc!=3) {
	fprintf(stderr,
		"Error: %s: missing --sleep parameter\n",name) ;
	usage(name) ;
	return 1 ;
      } else if (1 != sscanf(argv[2],"%f",&ztime)) {
	fprintf(stderr,
		"Error: %s: invalid sleep = %s\n",name, argv[2]) ;
	usage(name) ;
	return 1 ;
      } else if (ztime <= 0.f) {
	fprintf(stderr,
		"Error: %s: invalid sleep = %s\n",name, argv[2]) ;
	usage(name) ;
	return 1 ;
      } else {
	setSleep = 1 ;
      }
    } else {
      fprintf(stderr,
	      "Error: %s: unknown option: %s\n", name, argv[1]) ;
      usage(name) ;
      return 1 ;
      
    }
  }
  
  int nLines = 0 ;
  char **lines = (char **) malloc(sizeof(char*)*LINES) ;
  int i ;
  for (i=0; i<LINES; i++) 
    lines[i] = NULL ;


  // read data into memory
  while (running && ((getString(&(lines[nLines]))!=EOF))) {
    nLines++ ;
    if((nLines%LINES)==0) {
      lines = (char **) realloc(lines, (nLines+LINES)*sizeof(char*)) ;
      for (i=nLines; i<nLines+LINES; i++) 
	lines[i] = NULL ;
    }
  }
  
  // sleep if requested
  if (setSleep) {
    sleep((int)ztime) ;
    usleep((int)(1000000*(ztime-(int)ztime))) ;
  }
  
  // spew the data
  while (running) {
    for (i=0; i<nLines; i++) {
      printf("%s\n",lines[i]) ;
    }
  }
  
  // cleanup and exit
  free(lines) ;
  return 0 ;
}
